@@ -1,22 +1,25 @@
+# TODO(@nohehf): Make this a propper pytest test & run in CI
 import os
-from stack_graphs_python import index, query_definition, Position, Language
+from stack_graphs_python import index, Querier, Position, Language
 
 # index ./js_sample directory
 
 # convert ./js_sample directory to absolute path
 dir = os.path.abspath("./tests/js_sample")
-db = os.path.abspath("./js_sample.db")
+db_path = os.path.abspath("./db.sqlite")
 
 print("Indexing directory: ", dir)
-print("Database path: ", db)
+print("Database path: ", db_path)
 
-index([dir], db, language=Language.Python)
+index([dir], db_path, language=Language.JavaScript)
 
-source_reference: Position = Position(path=dir + "/index.js", line=2, column=12)
+source_reference = Position(path=dir + "/index.js", line=2, column=12)
 
 print("Querying definition for: ", source_reference.path)
 
-results = query_definition(source_reference, db)
+querier = Querier(db_path)
+
+results = querier.definitions(source_reference)
 
 print("Results: ", results)
 
